package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;

public final class LineNumber implements Cloneable, Node {
   private short startPc;
   private short lineNumber;

   LineNumber(DataInput file) throws IOException {
      this(file.readUnsignedShort(), file.readUnsignedShort());
   }

   public LineNumber(int startPc, int lineNumber) {
      this.startPc = (short)startPc;
      this.lineNumber = (short)lineNumber;
   }

   public LineNumber(LineNumber c) {
      this(c.getStartPC(), c.getLineNumber());
   }

   public void accept(Visitor v) {
      v.visitLineNumber(this);
   }

   public LineNumber copy() {
      try {
         return (LineNumber)this.clone();
      } catch (CloneNotSupportedException var2) {
         return null;
      }
   }

   public void dump(DataOutputStream file) throws IOException {
      file.writeShort(this.startPc);
      file.writeShort(this.lineNumber);
   }

   public int getLineNumber() {
      return this.lineNumber & '\uffff';
   }

   public int getStartPC() {
      return this.startPc & '\uffff';
   }

   public void setLineNumber(int lineNumber) {
      this.lineNumber = (short)lineNumber;
   }

   public void setStartPC(int startPc) {
      this.startPc = (short)startPc;
   }

   public String toString() {
      return "LineNumber(" + this.getStartPC() + ", " + this.getLineNumber() + ")";
   }
}
